Welcome
=======

Spin (short for SPanish INquisition) is a tool to create visualizations of a
group of devices based on HTML and SVG, mainly for the `MLZ Control Box
<https://forge.frm2.tum.de/public/doc/controlbox/master/html/>`_.

The Spin backend daemon is responsible for collecting values to display, sending
them to frontends, and acting on user interaction, such as mouse clicks.

.. toctree::
   :maxdepth: 2

   backend
   frontend
   api
   plugins
